@@ -48,7 +48,7 @@ MB = 1024 * 1024
 GB = 1024 * MB
 TB = 1024 * GB
 
-version = '0.1.0'
+version = '0.1.1'
 
 class S3Facts:
     amz_metadata_prefix = 'x-amz-meta-'
@@ -634,7 +634,7 @@ strings uniquely identifies the file within S3.
 The S3Name class is instantiated with a key and a bucket; the key 
 is required and the bucket defaults to None.
 
-The RemoteStore class methods take a *remote_name* argument which 
+The Storage class methods take a *remote_name* argument which 
 can be either a string which is the key, or an instance of the 
 S3Name class.  When no bucket is given (or the bucket is None) then 
 the default_bucket established when the connection is instantiated 
@@ -751,7 +751,7 @@ All methods return on success or raise StorageError on failure.
             if response.ok:
                 return not response.error, response.metadata
             else:
-                raise RemoteStoreError, 'exists: %s' % response.error
+                raise StorageError('exists', response.error)
         
         # Earlier, when the file does not exist, requests returned a 404 
         # with a non-empty reason.  Something must have changed!  
@@ -763,7 +763,7 @@ All methods return on success or raise StorageError on failure.
             if str(e) == 'IncompleteRead(0 bytes read)':
                 return False, {}
             else:
-                raise StorageError('exists', e)
+                raise StorageError('exists ChunkedEncodingError', e)
         except Exception, e:
             raise StorageError('exists ', e)
     
